#!/local/paths/perl -wT
#
# File: trim.pl
#
# Description: Trims the messages in a mailbox-type file (on standard
#              input), so it contains only those messages newer than
#              the number of days indicated by the argument.
#
# Author: Sylvain Robitaille
#
# Date: 2000/02/03
#

#
# First some directives for the compiler.
use strict;            # Everybody should use this, IM(NS)HO
use File::Basename;    # filename parsing
use Time::Local;       # time conversion


####################################################################
#
# CONFIGURATION section. Edit to your heart's content!

# Environment variables. Keep these to known safe values.
$ENV{PATH} = '/local/paths:/usr/bin';
$ENV{IFS}  = " \t\n";     # <space><tab><newline>
umask 077;

#
# End of configuration.
####################################################################


# Subroutine: Usage
#
# Description: Prints a usage message.
#
# Author: Sylvain Robitaille
#
# Date: 1998/02/02
#       1998/02/04: Add '-m recipient' option.
#
sub Usage {
  my $progname = basename($0, ());

  print STDERR <<USAGE;
    Usage: $progname <num>

    Reads from stdin, and prints to stdout messages that are newer
    than <num> days ago.
USAGE

exit 1;
}


# The main routine.
#
# Author: Sylvain Robitaille
#
# Date: 2000/02/03
#

# Who are we, anyway?
my $progname = basename $0;

if( $#ARGV != 0 ) {
  Usage;
}

my $since  = shift;
if( $since !~ m%^\d+$% ) {
  Usage;
}

my $target = time - $since * 24 * 60 * 60;
my $found  = 0;
my $time;

my %months = (
               'jan' => 0,
               'feb' => 1,
               'mar' => 2,
               'apr' => 3,
               'may' => 4,
               'jun' => 5,
               'jul' => 6,
               'aug' => 7,
               'sep' => 8,
               'oct' => 9,
               'nov' => 10,
               'dec' => 11
             );

while (<STDIN>) {
  #      $1                $2     $3     $4     $5    $6    $7      $8
  #      envelope from     day   month  date   hour   min   sec    year
  if( m%(^From \S+\@\S+) +(\w+) +(\w+) +(\d+) +(\d+):(\d+):(\d+)\D+(\d+)% ) {
    if( $target <= timelocal ($7, $6, $5, $4, $months{lc $3}, $8)) {
      $found = 1;
    } else {
      $found = 0;
    }
  };
  print if $found;
}
